==> 0.4.3.tar.gz: android/src/main/java/com/samelement/iot_notification/notification/MqttNotif.java <==
package com.samelement.iot_notification.notification;

import android.util.Log;

import com.samelement.iot_notification.analytic.Analytic;
import com.samelement.iot_notification.analytic.AnalyticOptions;
import com.samelement.iot_notification.device.Device;
import com.samelement.iot_notification.device.Node;
import com.samelement.iot_notification.device.NodeProperty;
import com.samelement.iot_notification.resource.Resource;

import java.util.Date;
import java.util.List;

public class MqttNotif {
    private Analytic analytic;
    private Resource resource;
    private Device device;
    private String topic;
    private boolean activeState;
    private Date lastMessageReceived;
    private String unit;

    public MqttNotif(Analytic analytic, Resource resource, Device device) {
        this.analytic = analytic;
        this.resource = resource;
        this.device = device;
        this.topic = device.getDeveloperId() + "/" + device.getSn() + "/" + resource.getParameter();
        this.unit = getUnitNodesFromParameter(device.getNodes(), resource.getParameter());
        this.activeState = initActiveState(analytic);
        this.lastMessageReceived = null;
    }

    public String getTopic() {
        return topic;
    }

    public Resource getResource() {
        return resource;
    }

    public Device getDevice() {
        return device;
    }

    public Analytic getAnalytic() {
        return analytic;
    }

    public boolean isActiveState() {
        return activeState;
    }

    public Date getLastMessageReceived() {
        return lastMessageReceived;
    }

    public void setLastMessageReceived(Date lastMessageReceived) {
        this.lastMessageReceived = lastMessageReceived;
    }

    public String getUnit() {
        if (unit == null) return "";

        return unit;
    }

    private static String getUnitNodesFromParameter(List<Node> nodes, String parameter) {
        String nodeId = getNodeIdFromParameter(parameter);
        String unit = "";

        if (nodes != null) {
            boolean found = false;
            for (Node n : nodes) {
                if (n.getId().equals(nodeId)) {
                    String resourceName = getResourceNameFromDeviceParameter(parameter);
                    if (n.getProperties() != null) {
                        for (NodeProperty prop : n.getProperties()) {
                            if (prop.getId().equals(resourceName)) {
                                if (prop.getUnit() != null) {
                                    unit = prop.getUnit();
                                    found = true;
                                }
                            }

                            if (found) break;
                        }
                    }
                }

                if (found) break;
            }
        }

        return unit;
    }

    // get resource name from device parameter
    // get humid from sensor/humid
    private static String getResourceNameFromDeviceParameter(String parameter) {
        String[] splitted = parameter.split("/");

        return splitted[splitted.length - 1];
    }

    private static String getNodeIdFromParameter(String parameter) {
        String[] splittedParameter = parameter.split("/");

        // node id with underscore
        String nodeId = splittedParameter[0];
        if (nodeId.contains("_")) {
            String[] splittedNodeId = nodeId.split("_");
            StringBuilder newNodeId = new StringBuilder();
            boolean first = true;
            for (int i = 0; i < splittedNodeId.length - 1; i++) {
                if (first)
                    first = false;
                else
                    newNodeId.append("_");

                newNodeId.append(splittedNodeId[i]);
            }

            nodeId = newNodeId.toString();
        }
        return nodeId;
    }

    private static boolean initActiveState(Analytic analytic) {
        boolean activeState = true;

        List<AnalyticOptions> chartOptions = analytic.getOptions();
        if (chartOptions != null &&
                chartOptions.size() > 0) {
            for (AnalyticOptions option : chartOptions
            ) {
                if (option.getId().equals("active-state")) {
                    if (option.getAction() != null) {
                        String value = option.getAction().getEnteredValue();
                        if (value != null && value.length() > 0) {
                            activeState = value.toLowerCase().equals("true");
                        }
                    }
                }
            }
        }

        return activeState;
    }
}

==> 0.5.8.tar.gz: android/src/main/java/com/samelement/iot_notification/notification/MqttNotif.java <==
package com.samelement.iot_notification.notification;

import android.util.Log;

import com.samelement.iot_notification.analytic.Analytic;
import com.samelement.iot_notification.analytic.AnalyticOptions;
import com.samelement.iot_notification.device.Device;
import com.samelement.iot_notification.device.Node;
import com.samelement.iot_notification.device.NodeProperty;
import com.samelement.iot_notification.resource.Resource;

import java.util.Date;
import java.util.List;

public class MqttNotif {
    private Analytic analytic;
    private Resource resource;
    private Device device;
    private String topic;
    private boolean activeState;
    private Date lastMessageReceived;
    private String unit;
    private int indexResource;

    public MqttNotif(Analytic analytic, Resource resource, Device device, int indexResource) {
        this.analytic = analytic;
        this.resource = resource;
        this.device = device;
        this.topic = device.getDeveloperId() + "/" + device.getSn() + "/" + resource.getParameter();
        this.unit = getUnitNodesFromParameter(device.getNodes(), resource.getParameter());
        this.activeState = initActiveState(analytic);
        this.lastMessageReceived = null;
        this.indexResource = indexResource;
    }

    public int getIndexResource() { return indexResource; }

    public String getTopic() {
        return topic;
    }

    public Resource getResource() {
        return resource;
    }

    public Device getDevice() {
        return device;
    }

    public Analytic getAnalytic() {
        return analytic;
    }

    public boolean isActiveState() {
        return activeState;
    }

    public Date getLastMessageReceived() {
        return lastMessageReceived;
    }

    public void setLastMessageReceived(Date lastMessageReceived) {
        this.lastMessageReceived = lastMessageReceived;
    }

    public String getUnit() {
        if (unit == null) return "";

        return unit;
    }

    private static String getUnitNodesFromParameter(List<Node> nodes, String parameter) {
        String nodeId = getNodeIdFromParameter(parameter);
        String unit = "";

        if (nodes != null) {
            boolean found = false;
            for (Node n : nodes) {
                if (n.getId().equals(nodeId)) {
                    String resourceName = getResourceNameFromDeviceParameter(parameter);
                    if (n.getProperties() != null) {
                        for (NodeProperty prop : n.getProperties()) {
                            if (prop.getId().equals(resourceName)) {
                                if (prop.getUnit() != null) {
                                    unit = prop.getUnit();
                                    found = true;
                                }
                            }

                            if (found) break;
                        }
                    }
                }

                if (found) break;
            }
        }

        return unit;
    }

    // get resource name from device parameter
    // get humid from sensor/humid
    private static String getResourceNameFromDeviceParameter(String parameter) {
        String[] splitted = parameter.split("/");

        return splitted[splitted.length - 1];
    }

    private static String getNodeIdFromParameter(String parameter) {
        String[] splittedParameter = parameter.split("/");

        // node id with underscore
        String nodeId = splittedParameter[0];
        if (nodeId.contains("_")) {
            String[] splittedNodeId = nodeId.split("_");
            StringBuilder newNodeId = new StringBuilder();
            boolean first = true;
            for (int i = 0; i < splittedNodeId.length - 1; i++) {
                if (first)
                    first = false;
                else
                    newNodeId.append("_");

                newNodeId.append(splittedNodeId[i]);
            }

            nodeId = newNodeId.toString();
        }
        return nodeId;
    }

    private static boolean initActiveState(Analytic analytic) {
        boolean activeState = true;

        List<AnalyticOptions> chartOptions = analytic.getOptions();
        if (chartOptions != null &&
                chartOptions.size() > 0) {
            for (AnalyticOptions option : chartOptions
            ) {
                if (option.getId().equals("active-state")) {
                    if (option.getAction() != null) {
                        String value = option.getAction().getEnteredValue();
                        if (value != null && value.length() > 0) {
                            activeState = value.toLowerCase().equals("true");
                        }
                    }
                }
            }
        }

        return activeState;
    }
}
